pub struct DMSCGatewayConfig {Show 13 fields
pub listen_address: String,
pub listen_port: u16,
pub max_connections: usize,
pub request_timeout_seconds: u64,
pub enable_rate_limiting: bool,
pub enable_circuit_breaker: bool,
pub enable_load_balancing: bool,
pub cors_enabled: bool,
pub cors_origins: Vec<String>,
pub cors_methods: Vec<String>,
pub cors_headers: Vec<String>,
pub enable_logging: bool,
pub log_level: String,
}Expand description
Configuration for the DMSC Gateway.
This struct defines the configuration options for the API gateway, including network settings, feature toggles, and CORS configuration.
Fields
listen_address: StringAddress to listen on
listen_port: u16Port to listen on
max_connections: usizeMaximum number of concurrent connections
request_timeout_seconds: u64Request timeout in seconds
enable_rate_limiting: boolWhether to enable rate limiting
enable_circuit_breaker: boolWhether to enable circuit breaker
enable_load_balancing: boolWhether to enable load balancing
cors_enabled: boolWhether to enable CORS
cors_origins: Vec<String>Allowed CORS origins
cors_methods: Vec<String>Allowed CORS methods
cors_headers: Vec<String>Allowed CORS headers
enable_logging: boolWhether to enable logging
log_level: StringLog level for gateway operations
Implementations